==> mapbox-navigation-accounts-android-0.2.0-sources.jar: com/mapbox/android/accounts/navigation/sku/v1/MauSku.java <==
package com.mapbox.android.accounts.navigation.sku.v1;

import android.content.SharedPreferences;
import android.os.SystemClock;
import android.support.annotation.Keep;
import android.text.TextUtils;

import com.mapbox.android.accounts.v1.MapboxAccounts;

import static com.mapbox.android.accounts.v1.AccountsConstants.KEY_PREFERENCE_MAPS_SKU_TOKEN;

/**
 * The class is responsible to request @link[MapboxAccounts.java] to generate the MAU token
 * and rotate the SKU token based on the refresh time
 */
public class MauSku implements SkuGenerator {

    private static final String KEY_PREFERENCE_NAV_MAU_SKU = "com.mapbox.navigation.accounts.mau.skutoken";
    private static final String KEY_PREFERENCE_NAV_USER_ID = "com.mapbox.navigation.accounts.mau.userid";
    private static final String KEY_PREFERENCE_NAV_MAU_TIMESTAMP = "com.mapbox.navigation.accounts.mau.timestamp";
    private static final long DEFAULT_TOKEN_TIMER = 0L;

    private SharedPreferences preferences;
    private long timerExpireAfter;

    @Keep
    public MauSku(SharedPreferences preferences, long timerExpireAfter) {
        this.preferences = preferences;
        this.timerExpireAfter = timerExpireAfter;
    }

    /**
     * Generates the SKU token
     * @return the SKU token
     */
    @Keep
    @Override
    public String generateToken() {
        refreshSkuToken();
        return retrieveMauSkuToken();
    }

    @Keep
    @Override
    public void onNavigationStart() {
    }

    /**
     * Sets the last time a request was made to DirectionsAPI to the default value
     */
    @Keep
    @Override
    public void onNavigationEnd() {
        setTimerExpiry(DEFAULT_TOKEN_TIMER);
    }

    private void refreshSkuToken() {
        if (!shouldRefreshSku()) {
            return;
        }
        setTimerExpiry(getNow());
        persistMauSkuToken();
        persistMapsSkuToken();
    }

    private boolean shouldRefreshSku() {
        return validateTimerExpiry();
    }

    private boolean validateTimerExpiry() {
        long skuTokenTimeStamp = getTimerExpiry();
        return isOneHoursExpired(skuTokenTimeStamp);
    }

    private void setTimerExpiry(long then) {
        preferences.edit().putLong(KEY_PREFERENCE_NAV_MAU_TIMESTAMP, then).apply();
    }

    private long getTimerExpiry() {
        return preferences.getLong(KEY_PREFERENCE_NAV_MAU_TIMESTAMP, DEFAULT_TOKEN_TIMER);
    }

    private void persistMauSkuToken() {
        String token = generateMauSkuToken();
        preferences.edit().putString(KEY_PREFERENCE_NAV_MAU_SKU, token).apply();
    }

    private String retrieveMauSkuToken() {
        return preferences.getString(KEY_PREFERENCE_NAV_MAU_SKU, "");
    }

    private void persistMapsSkuToken() {
        String mapsSkuToken = generateMapsSkuToken();
        preferences.edit().putString(KEY_PREFERENCE_MAPS_SKU_TOKEN, mapsSkuToken).apply();
    }

    private void persistMauUserId(String userId) {
        preferences.edit().putString(KEY_PREFERENCE_NAV_USER_ID, userId).apply();
    }

    private String retrieveUserId() {
        return preferences.getString(KEY_PREFERENCE_NAV_USER_ID, "");
    }

    private String getUserId() {
        String userId = retrieveUserId();
        if (TextUtils.isEmpty(userId)) {
            userId = generateUserId();
            persistMauUserId(userId);
        }
        return userId;
    }

    private String generateUserId() {
        return MapboxAccounts.obtainEndUserId();
    }

    private String generateMauSkuToken() {
        return MapboxAccounts.obtainNavigationSkuUserToken(getUserId());
    }

    private String generateMapsSkuToken() {
        return MapboxAccounts.obtainMapsSkuUserToken(getUserId());
    }

    private boolean isOneHoursExpired(long then) {
        return isExpired(getNow(), then);
    }

    private long getNow() {
        return SystemClock.elapsedRealtime();
    }

    private boolean isExpired(long now, long then) {
        return (now - then) / 1000 > timerExpireAfter;
    }
}

==> mapbox-navigation-accounts-android-0.4.0-sources.jar: com/mapbox/android/accounts/navigation/sku/v1/MauSku.java <==
package com.mapbox.android.accounts.navigation.sku.v1;

import android.annotation.SuppressLint;
import android.content.SharedPreferences;
import android.text.TextUtils;

import androidx.annotation.Keep;
import androidx.annotation.NonNull;

import com.mapbox.android.accounts.v1.MapboxAccounts;

import static com.mapbox.android.accounts.v1.AccountsConstants.KEY_PREFERENCE_MAPS_SKU_TOKEN;

/**
 * The class is responsible to request @link[MapboxAccounts.java] to generate the MAU token
 * and rotate the SKU token based on the refresh time
 */
public class MauSku implements SkuGenerator {

    private static final String KEY_PREFERENCE_NAV_MAU_SKU = "com.mapbox.navigation.accounts.mau.skutoken";
    private static final String KEY_PREFERENCE_NAV_USER_ID = "com.mapbox.navigation.accounts.mau.userid";
    private static final String KEY_PREFERENCE_NAV_MAU_TIMESTAMP = "com.mapbox.navigation.accounts.mau.timestamp";
    private static final long DEFAULT_TOKEN_TIMER = 0L;

    private SharedPreferences preferences;
    private long timerExpireAfter;
    private String applicationId;

    @Keep
    public MauSku(
            @NonNull SharedPreferences preferences,
            long timerExpireAfter,
            @NonNull String applicationId
    ) {
        this.preferences = preferences;
        this.applicationId = applicationId;
        this.timerExpireAfter = timerExpireAfter;
    }

    /**
     * Generates a SKU token. It also sets the route request count to default and timer to current time
     */
    @Keep
    @Override
    public void initializeSKU() {
        setTimerExpiry(getNow());
        persistMauSkuToken();
    }

    /**
     * Generates the SKU token
     * @return the SKU token
     */
    @Keep
    @Override
    public String generateToken() {
        refreshSkuToken();
        return retrieveNavMauSkuToken();
    }

    @Keep
    @Override
    public void onNavigationStart() {
    }

    /**
     * Sets the last time a request was made to DirectionsAPI to the default value
     */
    @Keep
    @Override
    public void onNavigationEnd() {
        setTimerExpiry(DEFAULT_TOKEN_TIMER);
    }

    private void refreshSkuToken() {
        if (!shouldRefreshSku()) {
            return;
        }
        setTimerExpiry(getNow());
        persistMauSkuToken();
    }

    private boolean shouldRefreshSku() {
        return validateTimerExpiry();
    }

    private boolean validateTimerExpiry() {
        long skuTokenTimeStamp = getTimerExpiry();
        return isOneHoursExpired(skuTokenTimeStamp);
    }

    @SuppressLint("ApplySharedPref")
    private void setTimerExpiry(long then) {
        preferences.edit().putLong(applicationId + "." + KEY_PREFERENCE_NAV_MAU_TIMESTAMP, then).commit();
    }

    private long getTimerExpiry() {
        return preferences.getLong(applicationId + "." + KEY_PREFERENCE_NAV_MAU_TIMESTAMP, DEFAULT_TOKEN_TIMER);
    }

    @SuppressLint("ApplySharedPref")
    private void persistMauSkuToken() {
        String token = generateNavMauSkuToken();
        preferences.edit().putString(applicationId + "." + KEY_PREFERENCE_NAV_MAU_SKU, token).commit();
        preferences.edit().putString(KEY_PREFERENCE_MAPS_SKU_TOKEN, token).commit();
    }

    private String retrieveNavMauSkuToken() {
        return preferences.getString(applicationId + "." + KEY_PREFERENCE_NAV_MAU_SKU, "");
    }

    @SuppressLint("ApplySharedPref")
    private void persistUserId(String userId) {
        preferences.edit().putString(applicationId + "." + KEY_PREFERENCE_NAV_USER_ID, userId).commit();
    }

    private String retrieveUserId() {
        return preferences.getString(applicationId + "." + KEY_PREFERENCE_NAV_USER_ID, "");
    }

    private String getUserId() {
        String userId = retrieveUserId();
        if (TextUtils.isEmpty(userId)) {
            userId = generateUserId();
            persistUserId(userId);
        }
        return userId;
    }

    private String generateUserId() {
        return MapboxAccounts.obtainEndUserId();
    }

    private String generateNavMauSkuToken() {
        return MapboxAccounts.obtainNavigationSkuUserToken(getUserId());
    }

    private boolean isOneHoursExpired(long then) {
        return isExpired(getNow(), then);
    }

    private long getNow() {
        return System.currentTimeMillis();
    }

    private boolean isExpired(long now, long then) {
        return (now - then) / 1000 > timerExpireAfter;
    }
}
